==> apache-cxf-3.1.18-src.zip: apache-cxf-3.1.18-src/rt/frontend/jaxws/src/test/java/org/apache/cxf/jaxws/service/HelloExcludeImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.service;

import java.util.ArrayList;
import java.util.List;

import javax.jws.WebService;

@WebService(endpointInterface = "org.apache.cxf.jaxws.service.HelloExcludeOnInterface")
public class HelloExcludeImpl implements HelloExcludeOnInterface {

    public String sayHi(String text) {
        return text;
    }
    
    public List<String> getGreetings() {
        List<String> strings = new ArrayList<String>();
        strings.add("Hello");
        strings.add("Bonjour");
        return strings;
    }

    public void sayGoodbye() {
    }

    public String[] getStringArray(String[] strs) {
        return null;
    }

    public List<String> getStringList(List<String> list) {
        return null;
    }

    public int echoExcluded(int i) {
        return 0;
    }

}

==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/rt/frontend/jaxws/src/test/java/org/apache/cxf/jaxws/service/HelloExcludeImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.service;

import java.util.ArrayList;
import java.util.List;

import javax.jws.WebService;

@WebService(endpointInterface = "org.apache.cxf.jaxws.service.HelloExcludeOnInterface")
public class HelloExcludeImpl implements HelloExcludeOnInterface {

    public String sayHi(String text) {
        return text;
    }

    public List<String> getGreetings() {
        List<String> strings = new ArrayList<>();
        strings.add("Hello");
        strings.add("Bonjour");
        return strings;
    }

    public void sayGoodbye() {
    }

    public String[] getStringArray(String[] strs) {
        return null;
    }

    public List<String> getStringList(List<String> list) {
        return null;
    }

    public int echoExcluded(int i) {
        return 0;
    }

}
